@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: logging.h 3053 2006-11-06 17:08:45Z roms $ */
-
-/*  libticables2 - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
+/*  libticables - link cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2002  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,20 +16,30 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TICABLES_LOGGING__
-#define __TICABLES_LOGGING__
+#ifndef LOGGING_H
+#define LOGGING_H
 
-#include <glib.h>
+#include <stdio.h>
 
-#define LOG_DOMAIN	"ticables"
+int start_logging();
+int log_data(int data);
+int stop_logging();
 
-void ticables_debug(const gchar *format, ...);
-void ticables_info(const gchar *format, ...);
-void ticables_message(const gchar *format, ...);
-void ticables_warning(const gchar *format, ...);
-void ticables_critical(const gchar *format, ...);
-void ticables_error(const gchar *format, ...);
+int start_void();
+int log_void();
+int stop_void();
 
-#define TRYC(x) { int aaa_; if((aaa_ = (x))) return aaa_; }
+/* uncomment it for enabling logging facilities */
+//#define LOGGING
+
+#ifdef LOGGING
+# define START_LOGGING(); start_logging();
+# define LOG_DATA(d);     log_data(d);
+# define STOP_LOGGING();  stop_logging();
+#else
+# define START_LOGGING();
+# define LOG_DATA(d);
+# define STOP_LOGGING();
+#endif
 
 #endif
